﻿<%@ WebHandler Language="C#" Class="Feed" %>

using System;
using System.Web;
using System.Xml.Serialization;
using Bitrix.DataLayer;
using Bitrix.Blog;
using ru.it_in;

public class Feed : IHttpHandler{
   
    public void ProcessRequest (HttpContext context)
    {
        //удаляем все из потока
        context.Response.Clear();
        //устанавливаем MIME-тип
        context.Response.ContentType = "text/xml";
        //устанавливаем кодировку UTF-8
        context.Response.ContentEncoding = System.Text.Encoding.UTF8;

        //создаем объект с фидом, выставляем основные настройки
        rss rssObj = new rss
                         {
                             version = "2.0",
                             channel = new RssChannel
                                           {
                                               description = "Новые записи в блоге IT-IN",
                                               language = "ru-RU",
                                               link = "http://www.it-in.ru",
                                               title = "Блог IT-IN",
                                               pubDate = DateTime.Now.ToUniversalTime()
                                           }
                         };

        //создаем фильтр для отсева черновиков
        BXFilter filter= new BXFilter();
        filter.Add(new BXFilterItem(BXBlogPost.Fields.IsPublished, BXSqlFilterOperators.Equal, true));
        //здесь можно добавить фильтр для отсева постов, у которых дата публикации в будущем
        
        //сортировка по дате публикации и Id
        BXOrderBy order = new BXOrderBy(new BXOrderByPair(BXBlogPost.Fields.DatePublished, BXOrderByDirection.Desc),
                                        new BXOrderByPair(BXBlogPost.Fields.Id, BXOrderByDirection.Desc));
        
        //забираем список постов
        BXBlogPostCollection postCollection = BXBlogPost.GetList(filter, order);
        
        //BXBlogPostChain будет переводить BBCode в HTML
        BXBlogPostChain chain = new BXBlogPostChain();
        
        //максимальное количество постов в фиде
        const int maxPosts = 10;
        
        //перебираем найденные посты
        int postsNum = maxPosts < postCollection.Count ? maxPosts : postCollection.Count;
        rssObj.channel.item = new RssChannelItem[postsNum];
        for (int i = 0; i < postsNum; i++)
        {
            RssChannelItem item = new RssChannelItem
                                      {
                                          title = postCollection[i].Title,
                                          description = chain.Process(postCollection[i].Content),
                                          link = "http://www.it-in.ru/blog/it-in/" + postCollection[i].Id + "/",
                                          pubDate = postCollection[i].DatePublished
                                      };
            rssObj.channel.item[i] = item;
        }
        
        
        //готовим XML и выводим XML в поток
        new XmlSerializer(typeof(rss)).Serialize(context.Response.Output, rssObj);
        //закрываем поток
        context.Response.End();

    }

    #region IHttpHandler Members

    public bool IsReusable
    {
        get { return false; }
    }

    #endregion
}